{% extends "account/password_change.html" %}
{% load i18n %}
{% load allauth_ui %}
{% load widget_tweaks %}
{% block content %}
    {% trans "Change Password" as heading %}
    {% #container heading=heading %}
    {% url 'account_change_password' as action_url %}
    {% #form form=form url=url button_text=heading %}
    {% csrf_token %}
    {{ redirect_field }}
    {% /form %}
    {% url "account_reset_password" as reset_password_url %}
    <a href="{{ reset_password_url }}" class="link">{% trans "Forgot Password?" %}</a>
    {% /container %}
{% endblock content %}
